@@ -3,8 +3,8 @@
 from pyrad import dictionary, packet, server
 
 class FakeServer(server.Server):
-	def _HandleAuthPacket(self, fd, pkt):
-		server.Server._HandleAuthPacket(self, fd, pkt)
+	def _HandleAuthPacket(self, pkt):
+		server.Server._HandleAuthPacket(self, pkt)
 
 		print "Received an authentication request"
 		print "Attributes: "
@@ -14,10 +14,10 @@ class FakeServer(server.Server):
 
 		reply=self.CreateReplyPacket(pkt)
 		reply.code=packet.AccessAccept
-		self.SendReplyPacket(fd, reply)
+		self.SendReplyPacket(pkt.fd, reply)
 	
-	def _HandleAcctPacket(self, fd, pkt):
-		server.Server._HandleAcctPacket(self, fd, pkt)
+	def _HandleAcctPacket(self, pkt):
+		server.Server._HandleAcctPacket(self, pkt)
 
 		print "Received an accounting request"
 		print "Attributes: "
@@ -26,7 +26,7 @@ class FakeServer(server.Server):
 		print
 
 		reply=self.CreateReplyPacket(pkt)
-		self.SendReplyPacket(fd, reply)
+		self.SendReplyPacket(pkt.fd, reply)
 
 
 srv=FakeServer(dict=dictionary.Dictionary("dictionary"))
